@@ -13,22 +13,34 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+
 from oslo_policy import policy
 
 from nova.policies import base
 
 
 BASE_POLICY_NAME = 'os_compute_api:os-flavor-rxtx'
-POLICY_ROOT = 'os_compute_api:os-flavor-rxtx:%s'
 
 
 flavor_rxtx_policies = [
-    policy.RuleDefault(
-        name=BASE_POLICY_NAME,
-        check_str=base.RULE_ADMIN_OR_OWNER),
-    policy.RuleDefault(
-        name=POLICY_ROOT % 'discoverable',
-        check_str=base.RULE_ANY),
+    policy.DocumentedRuleDefault(
+        BASE_POLICY_NAME,
+        base.RULE_ADMIN_OR_OWNER,
+        "Add the rxtx_factor key into some Flavor APIs",
+        [
+            {
+                'method': 'GET',
+                'path': '/flavors/detail'
+            },
+            {
+                'method': 'GET',
+                'path': '/flavors/{flavor_id}'
+            },
+            {
+                'method': 'POST',
+                'path': '/flavors'
+            },
+        ]),
 ]
 
 
