@@ -42,15 +42,39 @@ class TestNullSafeUtils(test.NoDBTestCase):
 
 class TestSendInstanceUpdateNotification(test.NoDBTestCase):
 
-    @mock.patch.object(base, 'info_from_instance',
-                       new_callable=mock.NonCallableMock)  # asserts not called
+    @mock.patch('nova.notifications.objects.base.NotificationBase.emit',
+                new_callable=mock.NonCallableMock)  # asserts not called
     # TODO(mriedem): Rather than mock is_enabled, it would be better to
     # configure oslo_messaging_notifications.driver=['noop']
     @mock.patch('nova.rpc.NOTIFIER.is_enabled', return_value=False)
-    def test_send_instance_update_notification_disabled(self, mock_enabled,
-                                                        mock_info):
-        """Tests the case that notifications are disabled which makes
-        send_instance_update_notification a noop.
+    def test_send_versioned_instance_update_notification_disabled(self,
+                                                                  mock_enabled,
+                                                                  mock_info):
+        """Tests the case that versioned notifications are disabled which makes
+        _send_versioned_instance_update_notification a noop.
         """
+        base._send_versioned_instance_update(mock.sentinel.ctxt,
+                                             mock.sentinel.instance,
+                                             mock.sentinel.payload,
+                                             mock.sentinel.host,
+                                             mock.sentinel.service)
+
+    @mock.patch.object(base, 'bandwidth_usage')
+    @mock.patch.object(base, '_compute_states_payload')
+    @mock.patch('nova.rpc.get_notifier')
+    @mock.patch.object(base, 'info_from_instance')
+    def test_send_legacy_instance_update_notification(self, mock_info,
+                                                      mock_get_notifier,
+                                                      mock_states,
+                                                      mock_bw):
+        """Tests the case that versioned notifications are disabled and
+        assert that this does not prevent sending the unversioned
+        instance.update notification.
+        """
+
+        self.flags(notification_format='unversioned', group='notifications')
         base.send_instance_update_notification(mock.sentinel.ctxt,
                                                mock.sentinel.instance)
+
+        mock_get_notifier.return_value.info.assert_called_once_with(
+            mock.sentinel.ctxt, 'compute.instance.update', mock.ANY)
