@@ -16,6 +16,8 @@
 
 import inspect
 
+import fixtures
+import mock
 import six
 from webob.util import status_reasons
 
@@ -110,6 +112,33 @@ class WrapExceptionTestCase(test.NoDBTestCase):
         self.assertEqual('nova.tests.unit.test_exception',
                          payload['module_name'])
 
+    @mock.patch('nova.rpc.NOTIFIER')
+    @mock.patch('nova.notifications.objects.exception.'
+                'ExceptionNotification.__init__')
+    def test_wrap_exception_notification_not_emitted_if_disabled(
+            self, mock_notification, mock_notifier):
+        mock_notifier.is_enabled.return_value = False
+
+        wrapped = exception_wrapper.wrap_exception(rpc.get_notifier('fake'),
+                                                   binary='fake-binary')
+        ctxt = context.get_admin_context()
+        self.assertRaises(test.TestingException,
+                          wrapped(bad_function_exception), 1, ctxt, 3, zoo=3)
+        self.assertFalse(mock_notification.called)
+
+    @mock.patch('nova.notifications.objects.exception.'
+                'ExceptionNotification.__init__')
+    def test_wrap_exception_notification_not_emitted_if_unversioned(
+            self, mock_notifier):
+        self.flags(notification_format='unversioned', group='notifications')
+
+        wrapped = exception_wrapper.wrap_exception(rpc.get_notifier('fake'),
+                                                   binary='fake-binary')
+        ctxt = context.get_admin_context()
+        self.assertRaises(test.TestingException,
+                          wrapped(bad_function_exception), 1, ctxt, 3, zoo=3)
+        self.assertFalse(mock_notifier.called)
+
 
 class NovaExceptionTestCase(test.NoDBTestCase):
     def test_default_error_msg(self):
@@ -183,6 +212,13 @@ class NovaExceptionTestCase(test.NoDBTestCase):
         self.assertEqual("some message", exc.format_message())
 
     def test_format_message_remote_error(self):
+        # NOTE(melwitt): This test checks that errors are formatted as expected
+        # in a real environment where format errors are caught and not
+        # reraised, so we patch in the real implementation.
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.exception.NovaException._log_exception',
+            test.NovaExceptionReraiseFormatError.real_log_exception))
+
         class FakeNovaException_Remote(exception.NovaException):
             msg_fmt = "some message %(somearg)s"
 
